@@ -1141,7 +1141,7 @@ def main():
     restart_music = True
     while enter_game:
         if(restart_music == True):
-            pygame.mixer.music.load('idle.wav')
+            pygame.mixer.music.load('PythonPals/idle.wav')
             pygame.mixer.music.play(-1)
 
         # start screen
